spannertools.get_spanners_attached_to_any_improper_parent_of_component
======================================================================

.. autofunction:: abjad.tools.spannertools.get_spanners_attached_to_any_improper_parent_of_component
